# usercustomize.py

from ideas.examples import lambda_encoding  # noqa

print(f"  --> {__file__} was executed")
